﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Xml;
using System.IO;

namespace Salesman_Import_XML_Creator
{
    public partial class Form1 : Form
    {
        string filePath;
        public Form1()
        {
            InitializeComponent();
        }
        
        private void BrowseXMLButton_Click(object sender, EventArgs e)
        {
            OpenFileDialog oFD = new OpenFileDialog();
            oFD.InitialDirectory = Environment.GetFolderPath(Environment.SpecialFolder.Desktop);
            oFD.Filter = "XML Files(*.xml)|*.xml;";
            oFD.FilterIndex = 1;
            oFD.RestoreDirectory = true;
            if (oFD.ShowDialog() == DialogResult.OK)
            {
                filePath = Path.GetFullPath(oFD.FileName);
            }
            OutputLabel.Text += "\r\nXML loaded";
        }

        private void SaveFileButton_Click(object sender, EventArgs e)
        {
            if (filePath == null ) 
            {
                System.Windows.Forms.MessageBox.Show("You have not selected an XML file yet", "Error", System.Windows.Forms.MessageBoxButtons.OK, System.Windows.Forms.MessageBoxIcon.Asterisk);
                return;
            }
            using (XmlReader reader = XmlReader.Create(filePath))
            {
                string minPrice = MinPriceTextBox.Text;
                string fallbackPrice = FallBackPriceTextBox.Text;
                string duration = DurationListBox.Text;
                string stacks = StacksTextBox.Text;
                string size = SizeTextBox.Text;
                string sellAll = SellAllCheckBox.Checked ? "true" : "false";
                string manual = ManualCheckBox.Checked ? "true" : "false";
                string[] searchForItemNames = SearchItemsTextBox.Text.Split(';');

                //Select location to save
                SaveFileDialog sFD = new SaveFileDialog();
                sFD.InitialDirectory = Environment.GetFolderPath(Environment.SpecialFolder.Desktop);
                sFD.Filter = "Salesman Files(*.sal)|*.sal;";
                sFD.FilterIndex = 1;
                sFD.RestoreDirectory = true;

                string saveFilePath = "";
                if (sFD.ShowDialog() == DialogResult.OK)
                {
                    saveFilePath = Path.GetFullPath(sFD.FileName);
                }
                OutputLabel.Text += "\r\nRunning...";
                if (saveFilePath == "")
                {
                    System.Windows.Forms.MessageBox.Show("You did not select a file location to save to", "Error", System.Windows.Forms.MessageBoxButtons.OK, System.Windows.Forms.MessageBoxIcon.Asterisk);
                    OutputLabel.Text += "\r\nError: No save path" + saveFilePath;
                    return;
                }

                //Empty the file
                System.IO.File.WriteAllText(@saveFilePath, string.Empty);

                StreamWriter outfile = new StreamWriter(saveFilePath, true);
                StringBuilder sb = new StringBuilder();                

                sb.Append("<?xml version=\"1.0\" encoding=\"utf-8\"?>\r\n");
                sb.Append("<ArrayOfAhItem xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\">\r\n");

                try
                {
                    while (reader.ReadToFollowing("item"))
                    {
                        string itemName = "";
                        int itemId = 0;
                        while (reader.MoveToNextAttribute())
                        {
                            if (reader.Name == "id")
                            {
                                itemId = Convert.ToInt32(reader.Value);
                            }
                            else if (reader.Name == "name")
                            {
                                itemName = reader.Value;
                            }
                        }
                        bool shouldAdd = false;
                        foreach (string s in searchForItemNames)
                        {
                            if (itemName.Contains(s))
                            {
                                shouldAdd = true;
                                break;
                            }
                        }
                        if (shouldAdd)
                        {
                            //<AhItem ItemId="42972" Cancel="true" Name="Glyph of Adrenaline Rush" MaxPriceTotal="3000000" MinPriceTotal="100000" DurationInt="12" Stacks="4" StackSize="1" SellAll="false" Manual="false" />
                            sb.Append("  <AhItem ItemId=\"" + itemId + "\" Cancel=\"true\" Name=\"" + itemName + "\" MaxPriceTotal=\"" + fallbackPrice + "\" MinPriceTotal=\"" + minPrice + "\" DurationInt=\"" + duration + "\" Stacks=\"" + stacks + "\" StackSize=\"" + size + "\" SellAll=\"" + sellAll + "\" Manual=\"" + manual + "\" />\r\n");
                        }
                    }
                }
                catch (Exception ex)
                {
                    System.Windows.Forms.MessageBox.Show("Error while parsing input XML, is it an XML from The Undermine Journal?" + ex, "Error", System.Windows.Forms.MessageBoxButtons.OK, System.Windows.Forms.MessageBoxIcon.Asterisk);
                    OutputLabel.Text += "\r\nXML Error";                    
                    outfile.Close();
                    return;
                }

                sb.Append("</ArrayOfAhItem>");

                outfile.Write(sb);
                outfile.Close();
                OutputLabel.Text += "\r\nDone! Saved to " + saveFilePath;
            }
        }        
    }
}
